@@ -342,7 +342,7 @@ typedef enum _MEDIA_EVENT
     EVENT_DECODE_CMD_HCP_INDOBJBASEADDRSTATE,      //! event for Decode HcpIndObjBaseAddrState Cmd
     EVENT_DECODE_CMD_HCP_SEGMENTSTATE_VP9,         //! event for Decode HcpVp9SegmentState Cmd
     EVENT_DECODE_CMD_HCP_PICSTATE_VP9,             //! event for Decode HcpVp9PicState Cmd
-    EVENT_DECODE_CMD_HCP_BSDOBJECT,                //! event for Decode HcpBsdObject Cmd
+    EVENT_DECODE_BUFFER_IQPARAM_AVC,               //! event for Decode AVC IQ Paramters
     EVENT_DECODE_BUFFER_PICPARAM_AV1,              //! event for Decode AV1 Pic Paramters
     EVENT_DECODE_BUFFER_SEGPARAM_AV1,              //! event for Decode AV1 Segment Paramters
     EVENT_DECODE_BUFFER_FILMGRAINPARAM_AV1,        //! event for Decode AV1 Film Grain Paramters
@@ -356,10 +356,10 @@ typedef enum _MEDIA_EVENT
     EVENT_DECODE_BUFFER_LONGSLICEPARAM_HEVC,       //! event for Decode HEVC Long Slice Paramters
     EVENT_DECODE_BUFFER_REXTLONGSLICEPARAM_HEVC,   //! event for Decode HEVC RExt Long Slice Paramters
     EVENT_DECODE_BUFFER_LONGSLICEPARAM_AVC,        //! event for Decode AVC Long Slice Paramters
-    EVENT_DECODE_FEATURE_MMC,                      //! event for Decode Feature MMC
-    EVENT_DECODE_FEATURE_VT_SCALABILITY,           //! event for Decode Feature Virtual Tile Scalability
-    EVENT_DECODE_FEATURE_RT_SCALABILITY,           //! event for Decode Feature Real Tile Scalability
-    EVENT_DECODE_FEATURE_DECODEMODE_REPORT,        //! event for Decode Feature Decode Mode Report
+    EVENT_DECODE_INFO_MMC,                         //! event for Decode Info MMC
+    EVENT_DECODE_INFO_SCALABILITY,                 //! event for Decode Info Scalability
+    EVENT_DECODE_INFO_SFC,                         //! event for Decode Info SFC
+    EVENT_DECODE_INFO_DECODEMODE_REPORT,           //! event for Decode Info Decode Mode Report
     EVENT_DECODE_DUMPINFO_DST,                     //! event for Decode Dst Dump Info
     EVENT_DECODE_DUMPINFO_REF,                     //! event for Decode Ref Dump Info
     EVENT_CALL_STACK,                              //! event for call stack dump
@@ -707,6 +707,34 @@ typedef enum _MT_LOG_ID
     MT_VP_BLT_MCPYPARAM,
     MT_VP_USERFEATURE_CTRL,
     MT_VP_FTR_REPORT,
+    MT_VP_FEATURE_GRAPTH_ID_BASE = 0x02000200,
+    MT_VP_FEATURE_GRAPTH_CREATESWFILTERPIPE_START,
+    MT_VP_FEATURE_GRAPTH_CREATESWFILTERPIPE_END,
+    MT_VP_FEATURE_GRAPTH_SETUPEXECUTESWFILTER_START,
+    MT_VP_FEATURE_GRAPTH_SETUPEXECUTESWFILTER_END,
+    MT_VP_FEATURE_GRAPTH_EXECUTEFILTER,
+    MT_VP_FEATURE_GRAPTH_SWFILTERALPHA,
+    MT_VP_FEATURE_GRAPTH_SWFILTERBLENDING,
+    MT_VP_FEATURE_GRAPTH_SWFILTERCGC,
+    MT_VP_FEATURE_GRAPTH_SWFILTERCOLORFILL,
+    MT_VP_FEATURE_GRAPTH_SWFILTERCSC,
+    MT_VP_FEATURE_GRAPTH_SWFILTERDEINTERLACE,
+    MT_VP_FEATURE_GRAPTH_SWFILTERDENOISE,
+    MT_VP_FEATURE_GRAPTH_SWFILTERHDR,
+    MT_VP_FEATURE_GRAPTH_SWFILTERLUMAKEY,
+    MT_VP_FEATURE_GRAPTH_SWFILTERPROCAMP,
+    MT_VP_FEATURE_GRAPTH_SWFILTERROTMIR,
+    MT_VP_FEATURE_GRAPTH_SWFILTERSCALING,
+    MT_VP_FEATURE_GRAPTH_SWFILTERSTE,
+    MT_VP_FEATURE_GRAPTH_SWFILTERTCC,
+    MT_VP_FEATURE_GRAPTH_SWFILTERACE,
+    MT_VP_FEATURE_GRAPTH_SWFILTERCAPPIPE,
+    MT_VP_FEATURE_GRAPTH_SWFILTERDV,
+    MT_VP_FEATURE_GRAPTH_SWFILTERFDFB,
+    MT_VP_FEATURE_GRAPTH_SWFILTERLACE,
+    MT_VP_FEATURE_GRAPTH_SWFILTERS3D,
+    MT_VP_FEATURE_GRAPTH_SWFILTERSECURECOPY,
+    MT_VP_FEATURE_GRAPTH_SWFILTERVEBOXUPDATE,
     MT_VP_HAL_ID_BASE = 0x02000400,
     MT_VP_HAL_PIPELINE_ADAPTER,
     MT_VP_HAL_PIPELINE_ADAPTER_EXT_ENTRY,
@@ -963,6 +991,73 @@ typedef enum _MT_PARAM_ID
     MT_VP_HAL_MMCINUSE,
     MT_VP_HAL_FRC_MODE,
     MT_VP_HAL_CAPTURE_PIPE,
+    MT_PARAM_ID_VP_FEATURE_GRAPH_BASE = 0x02001400,
+    MT_VP_FEATURE_GRAPH_FILTER_SWFILTERPIPE_COUNT,
+    MT_VP_FEATURE_GRAPH_FILTER_LAYERINDEXES_COUNT,
+    MT_VP_FEATURE_GRAPH_FILTER_INPUTCOLORSPACE,
+    MT_VP_FEATURE_GRAPH_FILTER_OUTPUTCOLORSPACE,
+    MT_VP_FEATURE_GRAPH_FILTER_INPUTFORMAT,
+    MT_VP_FEATURE_GRAPH_FILTER_OUTPUTFORMAT,
+    MT_VP_FEATURE_GRAPH_FILTER_FEATURETYPE,
+    MT_VP_FEATURE_GRAPH_FILTER_CALCULATINGALPHA,
+    MT_VP_FEATURE_GRAPH_FILTER_ALPHAMODE,
+    MT_VP_FEATURE_GRAPH_FILTER_FALPHA,
+    MT_VP_FEATURE_GRAPH_FILTER_BLENDTYPE,
+    MT_VP_FEATURE_GRAPH_FILTER_LUMAHIGH,
+    MT_VP_FEATURE_GRAPH_FILTER_LUMALOW,
+    MT_VP_FEATURE_GRAPH_FILTER_HDRMODE,
+    MT_VP_FEATURE_GRAPH_FILTER_LUTMODE,
+    MT_VP_FEATURE_GRAPH_FILTER_GPUGENERATE3DLUT,
+    MT_VP_FEATURE_GRAPH_FILTER_BRIGHTNESS,
+    MT_VP_FEATURE_GRAPH_FILTER_CONTRAST,
+    MT_VP_FEATURE_GRAPH_FILTER_HUE,
+    MT_VP_FEATURE_GRAPH_FILTER_SATURATION,
+    MT_VP_FEATURE_GRAPH_FILTER_DISABLECFINSFC,
+    MT_VP_FEATURE_GRAPH_FILTER_TCCRED,
+    MT_VP_FEATURE_GRAPH_FILTER_TCCGREEN,
+    MT_VP_FEATURE_GRAPH_FILTER_TCCBLUE,
+    MT_VP_FEATURE_GRAPH_FILTER_STEFACTOR,
+    MT_VP_FEATURE_GRAPH_FILTER_ENABLESTD,
+    MT_VP_FEATURE_GRAPH_FILTER_SAMPLETYPEINPUT,
+    MT_VP_FEATURE_GRAPH_FILTER_FMDKERNELENABLE,
+    MT_VP_FEATURE_GRAPH_FILTER_SINGLEFIELD,
+    MT_VP_FEATURE_GRAPH_FILTER_DIMODE,
+    MT_VP_FEATURE_GRAPH_FILTER_CHROMADN,
+    MT_VP_FEATURE_GRAPH_FILTER_LUMADN,
+    MT_VP_FEATURE_GRAPH_FILTER_AUTODETECT,
+    MT_VP_FEATURE_GRAPH_FILTER_HVSDN,
+    MT_VP_FEATURE_GRAPH_FILTER_DNFACTOR,
+    MT_VP_FEATURE_GRAPH_FILTER_SECUREDNNEED,
+    MT_VP_FEATURE_GRAPH_FILTER_ROTATION,
+    MT_VP_FEATURE_GRAPH_FILTER_INPUTHEIGHT,
+    MT_VP_FEATURE_GRAPH_FILTER_INPUTWIDTH,
+    MT_VP_FEATURE_GRAPH_FILTER_INPUTTILEMODE,
+    MT_VP_FEATURE_GRAPH_FILTER_OUTPUTHEIGHT,
+    MT_VP_FEATURE_GRAPH_FILTER_OUTPUTWIDTH,
+    MT_VP_FEATURE_GRAPH_FILTER_OUTPUTTILEMODE,
+    MT_VP_FEATURE_GRAPH_FILTER_ISCALINGTYPE,
+    MT_VP_FEATURE_GRAPH_FILTER_SCALINGMODE,
+    MT_VP_FEATURE_GRAPH_FILTER_GCOMPMODE,
+    MT_VP_FEATURE_GRAPH_FILTER_BT2020TORGB,
+    MT_VP_FEATURE_GRAPH_FILTER_ENABLEACE,
+    MT_VP_FEATURE_GRAPH_FILTER_ACELEVELCHANGED,
+    MT_VP_FEATURE_GRAPH_FILTER_ACELEVEL,
+    MT_VP_FEATURE_GRAPH_FILTER_ACESTRENGTH,
+    MT_VP_FEATURE_GRAPH_FILTER_ENABLECAPPIPE,
+    MT_VP_FEATURE_GRAPH_FILTER_LGCAKERNELENABLED,
+    MT_VP_FEATURE_GRAPH_FILTER_LGCAPHASE,
+    MT_VP_FEATURE_GRAPH_FILTER_1DLUTSIZE,
+    MT_VP_FEATURE_GRAPH_FILTER_3DLUTSIZE,
+    MT_VP_FEATURE_GRAPH_FILTER_ENABLEFB,
+    MT_VP_FEATURE_GRAPH_FILTER_ENABLEFD,
+    MT_VP_FEATURE_GRAPH_FILTER_ENABLEFLD,
+    MT_VP_FEATURE_GRAPH_FILTER_FDFBSTAGE,
+    MT_VP_FEATURE_GRAPH_FILTER_ENABLELACE,
+    MT_VP_FEATURE_GRAPH_FILTER_INPUTSAMPLETYPE,
+    MT_VP_FEATURE_GRAPH_FILTER_LACESTAGE,
+    MT_VP_FEATURE_GRAPH_FILTER_ENABLES3D,
+    MT_VP_FEATURE_GRAPH_FILTER_STEREOFORMAT,
+    MT_VP_FEATURE_GRAPH_FILTER_VEBOXSTATECOPYNEEDED,
     MT_PARAM_ID_VP_MHW_BASE = 0x02002000,
     MT_VP_MHW_VE_SCALABILITY_EN,
     MT_VP_MHW_VE_SCALABILITY_USE_SFC,
