@@ -1066,6 +1066,14 @@ namespace encode {
         // Set flag bIsMdfLoad in remote gaming scenario to boost GPU frequency for low latency
         cmdBuffer.Attributes.bFrequencyBoost = (m_seqParam->ScenarioInfo == ESCENARIO_REMOTEGAMING);
 
+        auto packetUtilities = m_pipeline->GetPacketUtilities();
+        ENCODE_CHK_NULL_RETURN(packetUtilities);
+        if (m_basicFeature->m_setMarkerEnabled)
+        {
+            PMOS_RESOURCE presSetMarker = m_osInterface->pfnGetMarkerResource(m_osInterface);
+            ENCODE_CHK_STATUS_RETURN(packetUtilities->SendMarkerCommand(&cmdBuffer, presSetMarker));
+        }
+
     #ifdef _MMC_SUPPORTED
         ENCODE_CHK_NULL_RETURN(m_mmcState);
         ENCODE_CHK_STATUS_RETURN(m_mmcState->SendPrologCmd(&cmdBuffer, false));
@@ -1078,6 +1086,12 @@ namespace encode {
         genericPrologParams.bMmcEnabled      = m_mmcState ? m_mmcState->IsMmcEnabled() : false;
         ENCODE_CHK_STATUS_RETURN(Mhw_SendGenericPrologCmdNext(&cmdBuffer, &genericPrologParams, m_miItf));
 
+        // Send predication command
+        if (m_basicFeature->m_predicationEnabled)
+        {
+            ENCODE_CHK_STATUS_RETURN(packetUtilities->SendPredicationCommand(&cmdBuffer));
+        }
+
         return MOS_STATUS_SUCCESS;
     }
 
