@@ -186,14 +186,18 @@ MOS_STATUS GpuContextSpecificNext::PatchGPUContextProtection(MOS_STREAM_HANDLE s
 MOS_STATUS GpuContextSpecificNext::Init3DCtx(PMOS_CONTEXT osParameters,
                 PMOS_GPUCTX_CREATOPTIONS createOption,
                 unsigned int *nengine,
-                struct i915_engine_class_instance *engine_map)
+                void *engine_map)
 {
     MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
 
-    m_i915Context[0] = mos_gem_context_create_shared(osParameters->bufmgr,
+    m_i915Context[0] = mos_context_create_shared(osParameters->bufmgr,
                                              osParameters->intel_context,
                                              I915_CONTEXT_CREATE_FLAGS_SINGLE_TIMELINE,
-                                             m_bProtectedContext);
+                                             m_bProtectedContext,
+                                             engine_map,
+                                             1,
+                                             *nengine,
+                                             0);
     if (m_i915Context[0] == nullptr)
     {
         MOS_OS_ASSERTMESSAGE("Failed to create context.\n");
@@ -210,7 +214,7 @@ MOS_STATUS GpuContextSpecificNext::Init3DCtx(PMOS_CONTEXT osParameters,
         return MOS_STATUS_UNKNOWN;
     }
 
-    if (mos_set_context_param_load_balance(m_i915Context[0], engine_map, *nengine))
+    if (mos_set_context_param_load_balance(m_i915Context[0], (struct i915_engine_class_instance *)engine_map, *nengine))
     {
         MOS_OS_ASSERTMESSAGE("Failed to set balancer extension.\n");
         return MOS_STATUS_UNKNOWN;
@@ -229,10 +233,10 @@ MOS_STATUS GpuContextSpecificNext::Init3DCtx(PMOS_CONTEXT osParameters,
             return MOS_STATUS_UNKNOWN;
         }
 
-        if (mos_hweight8(sseu.subslice_mask) > createOption->packed.SubSliceCount)
+        if (mos_hweight8(m_i915Context[0], sseu.subslice_mask) > createOption->packed.SubSliceCount)
         {
-            sseu.subslice_mask = mos_switch_off_n_bits(sseu.subslice_mask,
-                    mos_hweight8(sseu.subslice_mask)-createOption->packed.SubSliceCount);
+            sseu.subslice_mask = mos_switch_off_n_bits(m_i915Context[0], sseu.subslice_mask,
+                    mos_hweight8(m_i915Context[0], sseu.subslice_mask)-createOption->packed.SubSliceCount);
         }
 
         if (mos_set_context_param_sseu(m_i915Context[0], sseu))
@@ -247,16 +251,20 @@ MOS_STATUS GpuContextSpecificNext::Init3DCtx(PMOS_CONTEXT osParameters,
 
 MOS_STATUS GpuContextSpecificNext::InitComputeCtx(PMOS_CONTEXT osParameters,
                 unsigned int *nengine,
-                struct i915_engine_class_instance *engine_map,
+                void *engine_map,
                 MOS_GPU_NODE gpuNode,
                 bool *isEngineSelectEnable)
 {
     MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
 
-    m_i915Context[0] = mos_gem_context_create_shared(osParameters->bufmgr,
+    m_i915Context[0] = mos_context_create_shared(osParameters->bufmgr,
                                              osParameters->intel_context,
                                              I915_CONTEXT_CREATE_FLAGS_SINGLE_TIMELINE,
-                                             m_bProtectedContext);
+                                             m_bProtectedContext,
+                                             engine_map,
+                                             1,
+                                             *nengine,
+                                             0);
     if (m_i915Context[0] == nullptr)
     {
         MOS_OS_ASSERTMESSAGE("Failed to create context.\n");
@@ -276,7 +284,7 @@ MOS_STATUS GpuContextSpecificNext::InitComputeCtx(PMOS_CONTEXT osParameters,
 #if (_DEBUG || _RELEASE_INTERNAL)
     *isEngineSelectEnable = SelectEngineInstanceByUser(engine_map, nengine, m_engineInstanceSelect, gpuNode);
 #endif
-    if (mos_set_context_param_load_balance(m_i915Context[0], engine_map, *nengine))
+    if (mos_set_context_param_load_balance(m_i915Context[0], (struct i915_engine_class_instance *)engine_map, *nengine))
     {
         MOS_OS_ASSERTMESSAGE("Failed to set balancer extension.\n");
         return MOS_STATUS_UNKNOWN;
@@ -289,7 +297,7 @@ MOS_STATUS GpuContextSpecificNext::InitVdVeCtx(PMOS_CONTEXT osParameters,
                 MOS_STREAM_HANDLE streamState,
                 PMOS_GPUCTX_CREATOPTIONS createOption,
                 unsigned int *nengine,
-                struct i915_engine_class_instance *engine_map,
+                void *engine_map,
                 MOS_GPU_NODE gpuNode,
                 bool *isEngineSelectEnable)
 {
@@ -297,15 +305,20 @@ MOS_STATUS GpuContextSpecificNext::InitVdVeCtx(PMOS_CONTEXT osParameters,
 
     MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
 
-    m_i915Context[0] = mos_gem_context_create_shared(osParameters->bufmgr,
+    m_i915Context[0] = mos_context_create_shared(osParameters->bufmgr,
                                              osParameters->intel_context,
                                              I915_CONTEXT_CREATE_FLAGS_SINGLE_TIMELINE,
-                                             m_bProtectedContext);
+                                             m_bProtectedContext,
+                                             engine_map,
+                                             1,
+                                             *nengine,
+                                             0);
     if (m_i915Context[0] == nullptr)
     {
         MOS_OS_ASSERTMESSAGE("Failed to create context.\n");
         return MOS_STATUS_UNKNOWN;
     }
+    struct i915_engine_class_instance *_engine_map = (struct i915_engine_class_instance *)engine_map;
     m_i915Context[0]->pOsContext = osParameters;
 
     __u16 engine_class = (gpuNode == MOS_GPU_NODE_VE)? I915_ENGINE_CLASS_VIDEO_ENHANCE : I915_ENGINE_CLASS_VIDEO;
@@ -313,16 +326,16 @@ MOS_STATUS GpuContextSpecificNext::InitVdVeCtx(PMOS_CONTEXT osParameters,
 
     SetEngineQueryFlags(createOption, caps);
 
-    if (mos_query_engines(osParameters->bufmgr, engine_class, caps, nengine, engine_map))
+    if (mos_query_engines(osParameters->bufmgr, engine_class, caps, nengine, (void *)_engine_map))
     {
         MOS_OS_ASSERTMESSAGE("Failed to query engines.\n");
         return MOS_STATUS_UNKNOWN;
     }
 
 #if (_DEBUG || _RELEASE_INTERNAL)
-    *isEngineSelectEnable = SelectEngineInstanceByUser(engine_map, nengine, m_engineInstanceSelect, gpuNode);
+    *isEngineSelectEnable = SelectEngineInstanceByUser((void *)_engine_map, nengine, m_engineInstanceSelect, gpuNode);
 #endif
-    if (mos_set_context_param_load_balance(m_i915Context[0], engine_map, *nengine))
+    if (mos_set_context_param_load_balance(m_i915Context[0], _engine_map, *nengine))
     {
         MOS_OS_ASSERTMESSAGE("Failed to set balancer extension.\n");
         return MOS_STATUS_UNKNOWN;
@@ -332,10 +345,14 @@ MOS_STATUS GpuContextSpecificNext::InitVdVeCtx(PMOS_CONTEXT osParameters,
     {
         int i;
         //master queue
-        m_i915Context[1] = mos_gem_context_create_shared(osParameters->bufmgr,
+        m_i915Context[1] = mos_context_create_shared(osParameters->bufmgr,
                                                             osParameters->intel_context,
                                                             I915_CONTEXT_CREATE_FLAGS_SINGLE_TIMELINE,
-                                                            m_bProtectedContext);
+                                                            m_bProtectedContext,
+                                                            (void *)_engine_map,
+                                                            1,
+                                                            1,
+                                                            0);
         if (m_i915Context[1] == nullptr)
         {
             MOS_OS_ASSERTMESSAGE("Failed to create master context.\n");
@@ -343,7 +360,7 @@ MOS_STATUS GpuContextSpecificNext::InitVdVeCtx(PMOS_CONTEXT osParameters,
         }
         m_i915Context[1]->pOsContext = osParameters;
 
-        if (mos_set_context_param_load_balance(m_i915Context[1], engine_map, 1))
+        if (mos_set_context_param_load_balance(m_i915Context[1], _engine_map, 1))
         {
             MOS_OS_ASSERTMESSAGE("Failed to set master context bond extension.\n");
             return MOS_STATUS_UNKNOWN;
@@ -352,10 +369,14 @@ MOS_STATUS GpuContextSpecificNext::InitVdVeCtx(PMOS_CONTEXT osParameters,
         //slave queue
         for (i=1; i < *nengine; i++)
         {
-            m_i915Context[i+1] = mos_gem_context_create_shared(osParameters->bufmgr,
+            m_i915Context[i+1] = mos_context_create_shared(osParameters->bufmgr,
                                                                 osParameters->intel_context,
                                                                 I915_CONTEXT_CREATE_FLAGS_SINGLE_TIMELINE,
-                                                                m_bProtectedContext);
+                                                                m_bProtectedContext,
+                                                                (void *)_engine_map,
+                                                                1,
+                                                                1,
+                                                                0);
             if (m_i915Context[i+1] == nullptr)
             {
                 MOS_OS_ASSERTMESSAGE("Failed to create slave context.\n");
@@ -363,13 +384,13 @@ MOS_STATUS GpuContextSpecificNext::InitVdVeCtx(PMOS_CONTEXT osParameters,
             }
             m_i915Context[i+1]->pOsContext = osParameters;
 
-            if (mos_set_context_param_bond(m_i915Context[i+1], engine_map[0], &engine_map[i], 1) != S_SUCCESS)
+            if (mos_set_context_param_bond(m_i915Context[i+1], _engine_map[0], &_engine_map[i], 1) != S_SUCCESS)
             {
                 int err = errno;
                 if (err == ENODEV)
                 {
-                    mos_gem_context_destroy(m_i915Context[1]);
-                    mos_gem_context_destroy(m_i915Context[i+1]);
+                    mos_context_destroy(m_i915Context[1]);
+                    mos_context_destroy(m_i915Context[i+1]);
                     m_i915Context[i+1] = nullptr;
                     break;
                 }
@@ -391,14 +412,18 @@ MOS_STATUS GpuContextSpecificNext::InitVdVeCtx(PMOS_CONTEXT osParameters,
             for(i = 1; i < *nengine; i++)
             {
                 unsigned int ctxWidth = i + 1;
-                m_i915Context[i] = mos_gem_context_create_shared(osParameters->bufmgr,
+                m_i915Context[i] = mos_context_create_shared(osParameters->bufmgr,
                                                              osParameters->intel_context,
                                                              0, // I915_CONTEXT_CREATE_FLAGS_SINGLE_TIMELINE not allowed for parallel submission
-                                                             m_bProtectedContext);
-                if (mos_set_context_param_parallel(m_i915Context[i], engine_map, ctxWidth) != S_SUCCESS)
+                                                             m_bProtectedContext,
+                                                             (void *)_engine_map,
+                                                             ctxWidth,
+                                                             1,
+                                                             0);
+                if (mos_set_context_param_parallel(m_i915Context[i], _engine_map, ctxWidth) != S_SUCCESS)
                 {
                     MOS_OS_ASSERTMESSAGE("Failed to set parallel extension since discontinuous logical engine.\n");
-                    mos_gem_context_destroy(m_i915Context[i]);
+                    mos_context_destroy(m_i915Context[i]);
                     m_i915Context[i] = nullptr;
                     break;
                 }
@@ -411,16 +436,20 @@ MOS_STATUS GpuContextSpecificNext::InitVdVeCtx(PMOS_CONTEXT osParameters,
 
 MOS_STATUS GpuContextSpecificNext::InitBltCtx(PMOS_CONTEXT osParameters,
                 unsigned int *nengine,
-                struct i915_engine_class_instance *engine_map)
+                void *engine_map)
 {
     MOS_OS_FUNCTION_ENTER;
 
     MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
 
-    m_i915Context[0] = mos_gem_context_create_shared(osParameters->bufmgr,
+    m_i915Context[0] = mos_context_create_shared(osParameters->bufmgr,
                                              osParameters->intel_context,
                                              I915_CONTEXT_CREATE_FLAGS_SINGLE_TIMELINE,
-                                             m_bProtectedContext);
+                                             m_bProtectedContext,
+                                             engine_map,
+                                             1,
+                                             *nengine,
+                                             0);
     if (m_i915Context[0] == nullptr)
     {
         MOS_OS_ASSERTMESSAGE("Failed to create context.\n");
@@ -437,7 +466,7 @@ MOS_STATUS GpuContextSpecificNext::InitBltCtx(PMOS_CONTEXT osParameters,
         return MOS_STATUS_UNKNOWN;
     }
 
-    if (mos_set_context_param_load_balance(m_i915Context[0], engine_map, *nengine))
+    if (mos_set_context_param_load_balance(m_i915Context[0], (struct i915_engine_class_instance *)engine_map, *nengine))
     {
         MOS_OS_ASSERTMESSAGE("Failed to set balancer extension.\n");
         return MOS_STATUS_UNKNOWN;
@@ -549,20 +578,20 @@ MOS_STATUS GpuContextSpecificNext::Init(OsContextNext *osContext,
 
         if (gpuNode == MOS_GPU_NODE_3D)
         {
-            eStatus = Init3DCtx(osParameters, createOption, &nengine, engine_map);
+            eStatus = Init3DCtx(osParameters, createOption, &nengine, (void *)engine_map);
         }
         else if (gpuNode == MOS_GPU_NODE_COMPUTE)
         {
-            eStatus = InitComputeCtx(osParameters, &nengine, engine_map, gpuNode, &isEngineSelectEnable);
+            eStatus = InitComputeCtx(osParameters, &nengine, (void *)engine_map, gpuNode, &isEngineSelectEnable);
         }
         else if (gpuNode == MOS_GPU_NODE_VIDEO || gpuNode == MOS_GPU_NODE_VIDEO2
                 || gpuNode == MOS_GPU_NODE_VE)
         {
-            eStatus = InitVdVeCtx(osParameters, streamState, createOption, &nengine, engine_map, gpuNode, &isEngineSelectEnable);
+            eStatus = InitVdVeCtx(osParameters, streamState, createOption, &nengine, (void *)engine_map, gpuNode, &isEngineSelectEnable);
         }
         else if (gpuNode == MOS_GPU_NODE_BLT)
         {
-            eStatus = InitBltCtx(osParameters, &nengine, engine_map);
+            eStatus = InitBltCtx(osParameters, &nengine, (void *)engine_map);
         }
         else
         {
@@ -633,7 +662,7 @@ void GpuContextSpecificNext::Clear()
     {
         if (m_i915Context[i])
         {
-            mos_gem_context_destroy(m_i915Context[i]);
+            mos_context_destroy(m_i915Context[i]);
             m_i915Context[i] = nullptr;
         }
     }
@@ -1249,7 +1278,7 @@ MOS_STATUS GpuContextSpecificNext::SubmitCommandBuffer(
             resource));
 
         uint64_t boOffset = alloc_bo->offset64;
-        if (!mos_gem_bo_is_softpin(alloc_bo))
+        if (!mos_bo_is_softpin(alloc_bo))
         {
             if (alloc_bo != tempCmdBo)
             {
@@ -1284,7 +1313,7 @@ MOS_STATUS GpuContextSpecificNext::SubmitCommandBuffer(
             {
                 if (it->second->OsResource.bo == tempCmdBo &&
                     it->second->iSubmissionType & SUBMISSION_TYPE_MULTI_PIPE_SLAVE &&
-                    !mos_gem_bo_is_exec_object_async(alloc_bo))
+                    !mos_bo_is_exec_object_async(alloc_bo))
                 {
                     skipSyncBoList.push_back(alloc_bo);
                     break;
@@ -1293,7 +1322,7 @@ MOS_STATUS GpuContextSpecificNext::SubmitCommandBuffer(
             }
         }
         else if (cmdBuffer->iSubmissionType & SUBMISSION_TYPE_MULTI_PIPE_SLAVE &&
-                 !mos_gem_bo_is_exec_object_async(alloc_bo))
+                 !mos_bo_is_exec_object_async(alloc_bo))
         {
             skipSyncBoList.push_back(alloc_bo);
         }
@@ -1307,7 +1336,7 @@ MOS_STATUS GpuContextSpecificNext::SubmitCommandBuffer(
         }
 #endif
 
-        if(mos_gem_bo_is_softpin(alloc_bo))
+        if(mos_bo_is_softpin(alloc_bo))
         {
             if (alloc_bo != tempCmdBo)
             {
@@ -1317,7 +1346,7 @@ MOS_STATUS GpuContextSpecificNext::SubmitCommandBuffer(
         else
         {
             // This call will patch the command buffer with the offsets of the indirect state region of the command buffer
-            ret = mos_bo_emit_reloc2(
+            ret = mos_bo_emit_reloc(
                 tempCmdBo,                                                         // Command buffer
                 currentPatch->PatchOffset,                                         // Offset in the command buffer
                 alloc_bo,                                                          // Allocation object for which the patch will be made.
@@ -1516,7 +1545,7 @@ MOS_STATUS GpuContextSpecificNext::SubmitCommandBuffer(
             }
             else
             {
-                ret = mos_gem_bo_context_exec2(cmd_bo,
+                ret = mos_bo_context_exec2(cmd_bo,
                     m_commandBufferSize,
                     m_i915Context[0],
                     cliprects,
@@ -1528,7 +1557,7 @@ MOS_STATUS GpuContextSpecificNext::SubmitCommandBuffer(
         }
         else
         {
-            ret = mos_gem_bo_context_exec2(cmd_bo,
+            ret = mos_bo_context_exec2(cmd_bo,
                 m_commandBufferSize,
                 perStreamParameters->intel_context,
                 cliprects,
@@ -1589,7 +1618,7 @@ if (streamState->dumpCommandBuffer)
         MOS_OS_CHK_NULL_RETURN(currentPatch);
 
         if(currentPatch->cmdBo)
-            mos_gem_bo_clear_relocs(currentPatch->cmdBo, 0);
+            mos_bo_clear_relocs(currentPatch->cmdBo, 0);
     }
 
     it = m_secondaryCmdBufs.begin();
@@ -1704,7 +1733,7 @@ int32_t GpuContextSpecificNext::SubmitPipeCommands(
         queue = m_i915Context[1];
     }
 
-    ret = mos_gem_bo_context_exec2(cmdBo,
+    ret = mos_bo_context_exec2(cmdBo,
                                   cmdBo->size,
                                   queue,
                                   nullptr,
@@ -1759,7 +1788,7 @@ int32_t GpuContextSpecificNext::ParallelSubmitCommands(
             fenceFlag = I915_EXEC_FENCE_OUT;
             queue = m_i915Context[0];
 
-            ret = mos_gem_bo_context_exec2(it->second->OsResource.bo,
+            ret = mos_bo_context_exec2(it->second->OsResource.bo,
                                   it->second->OsResource.bo->size,
                                   queue,
                                   nullptr,
@@ -1785,7 +1814,7 @@ int32_t GpuContextSpecificNext::ParallelSubmitCommands(
                     fenceFlag = I915_EXEC_FENCE_IN;
                 }
 
-                ret = mos_gem_bo_context_exec3(cmdBos,
+                ret = mos_bo_context_exec3(cmdBos,
                                               numBos,
                                               queue,
                                               nullptr,
@@ -1918,10 +1947,11 @@ PMOS_RESOURCE GpuContextSpecificNext::GetOcaRTLogResource(PMOS_RESOURCE globalIn
 }
 
 #if (_DEBUG || _RELEASE_INTERNAL)
-bool GpuContextSpecificNext::SelectEngineInstanceByUser(struct i915_engine_class_instance *engineMap,
+bool GpuContextSpecificNext::SelectEngineInstanceByUser(void *engine_map,
         uint32_t *engineNum, uint32_t userEngineInstance, MOS_GPU_NODE gpuNode)
 {
     uint32_t engineInstance     = 0x0;
+    struct i915_engine_class_instance *engineMap = (struct i915_engine_class_instance *)engine_map;
 
     if(gpuNode == MOS_GPU_NODE_COMPUTE)
     {
